#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class initial_fraction_of_bridges_in_coal_lattice(Real):
    """
    'initial_fraction_of_bridges_in_coal_lattice' child.
    """

    fluent_name = "initial-fraction-of-bridges-in-coal-lattice"

