#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class capillary_pressure_as_diffusion(Boolean):
    """
    Model capillary pressure as diffusion.
    """

    fluent_name = "capillary-pressure-as-diffusion?"

